pub struct Id(/* private fields */);Expand description
Name of a node, param, variable, type, package, model, etc., as it appears in the declaration
This is simply a cheap newtype around String.
Example values
- Nodes:
sin,adder,map - Variables:
a,b,cin - Types:
state - Packages:
Lustre
Usage
Ids do not remember their source span. Therefore, queries that rely on it may want to require both to be given, or to compute the Id inside them. Ids without an accompanying span should only be used as inputs to query that don’t report the errors themselves.